
#include "TEffHistogram.h"
#include <TCanvas.h>
#include "TCollection.h"
#include "TList.h"

ClassImp(TEffHistogram)

#include <string>


TEffHistogram::TEffHistogram(const char *name, Int_t nbinsx, Double_t xlow, Double_t xup)
{
    SetName(name);
    _histo_all = new TH1F((name + std::string("_all")).c_str(),
           "all", nbinsx, xlow, xup);
    _histo_sel = new TH1F((name + std::string("_sel")).c_str(),
           "selected", nbinsx, xlow, xup);
}


TEffHistogram::TEffHistogram(const TEffHistogram& rhs)
    : TNamed()
{
    _histo_all = static_cast<TH1F*>(rhs._histo_all->Clone());
    _histo_sel = static_cast<TH1F*>(rhs._histo_sel->Clone());
}


TEffHistogram::~TEffHistogram()
{
    delete _histo_sel;
    delete _histo_all;
}


void TEffHistogram::Fill(bool selected, double var)
{
    if (selected) {
       _histo_sel->Fill(var);
    }
    _histo_all->Fill(var);
    Info("Fill", "%d %f", selected, var);
}


void TEffHistogram::Merge(TCollection *list)
{ 
   if (!list) return;
   if (list->IsEmpty()) return;
   
   TIter next(list);
   while (TObject *o = next()) {
      TEffHistogram *temp = dynamic_cast<TEffHistogram*>(o);
      if (temp) {
         _histo_all->Add(temp->_histo_all);
         _histo_sel->Add(temp->_histo_sel);
      }
   }
   return;
}

void TEffHistogram::Draw(Option_t *)
{ 

   TCanvas *c1 = new TCanvas("c1","TestSel canvas",200,10,700,700);
   c1->Divide(1,2,0,0);

   if (_histo_all) {
      c1->cd(1);
      _histo_all->SetFillColor(kBlue);
      _histo_all->Draw();
      if (_histo_sel) {
         _histo_sel->SetFillColor(kRed);
         c1->cd(2);
         _histo_sel->Draw();
      } else {
         Warning("Draw", "_histo_sel is undefined!");
      }
   } else {
      Warning("Draw", "_histo_all is undefined!");
   }

   // Final update
   c1->cd();
   c1->Update();
}
