#define TestSel_cxx
//////////////////////////////////////////////////////////
//
// Example of TSelector implementation to do generic
// processing (filling a set of histograms in this case).
// See tutorials/proof/runProof.C, option "simple", for an
// example of how to run this selector.
//
//////////////////////////////////////////////////////////

#include "TestSel.h"
#include <TCanvas.h>
#include <TFrame.h>
#include <TPaveText.h>
#include <TFormula.h>
#include <TF1.h>
#include <TEffHistogram.h>
#include <TMath.h>
#include <TRandom3.h>
#include <TString.h>
#include <TStyle.h>
#include <TSystem.h>
#include <TParameter.h>
#include <TProofServ.h>

//_____________________________________________________________________________
TestSel::TestSel()
{
   // Constructor

   fEffHist = 0;
   fRandom = 0;
}

//_____________________________________________________________________________
TestSel::~TestSel()
{
   // Destructor

   if (fRandom) delete fRandom;
}

//_____________________________________________________________________________
void TestSel::Begin(TTree * /*tree*/)
{
   // The Begin() function is called at the start of the query.
   // When running with PROOF Begin() is only called on the client.
   // The tree argument is deprecated (on PROOF 0 is passed).

   TString option = GetOption();

//   fEffHist = new TEffHistogram("testEff", 100, -3., 3.);
}

//_____________________________________________________________________________
void TestSel::SlaveBegin(TTree * /*tree*/)
{
   // The SlaveBegin() function is called after the Begin() function.
   // When running with PROOF SlaveBegin() is called on each slave server.
   // The tree argument is deprecated (on PROOF 0 is passed).

   TString option = GetOption();

   fEffHist = new TEffHistogram("testEff", 100, -3., 3.);
//   fEffHist->SetFillColor(kRed);
   fOutput->Add(fEffHist);

   // Set random seed
   fRandom = new TRandom3(0);
}

//_____________________________________________________________________________
Bool_t TestSel::Process(Long64_t)
{
   // The Process() function is called for each entry in the tree (or possibly
   // keyed object in the case of PROOF) to be processed. The entry argument
   // specifies which entry in the currently loaded tree is to be processed.
   // It can be passed to either TestSel::GetEntry() or TBranch::GetEntry()
   // to read either all or the required parts of the data. When processing
   // keyed objects with PROOF, the object is already loaded and is available
   // via the fObject pointer.
   //
   // This function should contain the "body" of the analysis. It can contain
   // simple or elaborate selection criteria, run algorithms on the data
   // of the event and typically fill histograms.
   //
   // The processing can be stopped by calling Abort().
   //
   // Use fStatus to set the return value of TTree::Process().
   //
   // The return value is currently not used.

   
   Double_t x = fRandom->Gaus(0.,1.);
   Double_t w = fRandom->Rndm();
   Bool_t sel = (w > .8) ? 1 : 0;
   
   fEffHist->Fill(sel, x);

   return kTRUE;
}

//_____________________________________________________________________________
void TestSel::SlaveTerminate()
{
   // The SlaveTerminate() function is called after all entries or objects
   // have been processed. When running with PROOF SlaveTerminate() is called
   // on each slave server.

}

//_____________________________________________________________________________
void TestSel::Terminate()
{
   // The Terminate() function is the last function to be called during
   // a query. It always runs on the client, it can be used to present
   // the results graphically or save the results to file.

   //
   // Create a canvas, with 100 pads
   //
   fEffHist = dynamic_cast<TEffHistogram *>(fOutput->FindObject("testEff"));
   if (fEffHist) fEffHist->Draw();
}
